@@ -1,4 +1,4 @@
-package Pcore::API::Majestic v0.7.1;
+package Pcore::API::Majestic v0.8.0;
 
 use Pcore -dist, -class, -const, -result, -export => { CONST => [qw[$MAJESTIC_INDEX_FRESH $MAJESTIC_INDEX_HISTORIC]] };
 
@@ -21,6 +21,7 @@ sub get_subscription_info ( $self, $cb ) {
     return;
 }
 
+# https://developer-support.majestic.com/api/commands/get-index-item-info.shtml
 sub get_index_item_info ( $self, $domains, $datasource, $failover, $cb ) {
     die q[Maximum items number is 100] if $domains->@* > 100;
 
@@ -55,6 +56,36 @@ sub get_index_item_info ( $self, $domains, $datasource, $failover, $cb ) {
     return;
 }
 
+# https://developer-support.majestic.com/api/commands/get-back-link-data.shtml
+sub get_backlink_data ( $self, $domain, $params, $cb ) {
+    my $url_params = {
+        cmd                        => 'GetBackLinkData',
+        datasource                 => 'fresh',
+        item                       => $domain,
+        Count                      => 100,                 # Number of results to be returned back. Max. 50_000
+        Mode                       => 0,
+        ShowDomainInfo             => 0,
+        MaxSourceURLsPerRefDomain  => -1,
+        MaxSameSourceURLs          => -1,
+        RefDomain                  => undef,
+        FilterTopic                => undef,
+        FilterTopicsRefDomainsMode => 0,
+        UsePrefixScan              => 0,
+        defined $params ? $params->%* : (),
+    };
+
+    $self->_request(
+        $url_params,
+        sub ($res) {
+            $cb->($res);
+
+            return;
+        }
+    );
+
+    return;
+}
+
 sub _request ( $self, $url_params, $cb ) {
     if ( $self->api_key ) {
         $url_params->{app_api_key} = $self->api_key;
